==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Lang/src/model/actor/ActorScriptValidator.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_ACTORSCRIPTVALIDATOR_H_
#define _U2_ACTORSCRIPTVALIDATOR_H_

#include "ActorValidator.h"

namespace U2 {
namespace Workflow {

class ActorScriptValidator : public ActorValidator {
public:
    virtual bool validate(const Actor *actor, NotificationsList &notificationList, const QMap<QString, QString> &options) const;
};

class ValidationContext : public QObject {
    Q_OBJECT
public:
    ValidationContext(QScriptEngine &engine, const Actor *actor);

    NotificationsList notifications() const;
    bool hasErrors() const;

public slots:
    QScriptValue attributeValue(const QString &attrId);
    void error(const QString &message);
    void warning(const QString &message);

private:
    QScriptEngine &engine;
    const Actor *actor;
    QStringList errors;
    QStringList warnings;
};

}  // namespace Workflow
}  // namespace U2

#endif  // _U2_ACTORSCRIPTVALIDATOR_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/corelibs/U2Lang/src/model/actor/ActorScriptValidator.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include "ActorValidator.h"

namespace U2 {
namespace Workflow {

class ActorScriptValidator : public ActorValidator {
public:
    virtual bool validate(const Actor* actor, NotificationsList& notificationList, const QMap<QString, QString>& options) const;
};

class ValidationContext : public QObject {
    Q_OBJECT
public:
    ValidationContext(QScriptEngine& engine, const Actor* actor);

    NotificationsList notifications() const;
    bool hasErrors() const;

public slots:
    QScriptValue attributeValue(const QString& attrId);
    void error(const QString& message);
    void warning(const QString& message);

private:
    QScriptEngine& engine;
    const Actor* actor;
    QStringList errors;
    QStringList warnings;
};

}  // namespace Workflow
}  // namespace U2
